@@ -5,12 +5,13 @@ use File::Spec;
 use Config::Simple;
 use Hash::Merge qw/merge/;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 our $RC;
 
 our $RC_DIRS = ($^O =~ m!Win32!) ? [
     # TODO: better windows support
+    '.',
     $ENV{CMDRC_DIR},
     $ENV{HOME},
 ] : [
@@ -39,6 +40,10 @@ sub read {
 
     my ($file, $dir, $loader) = _get_args(@_);
 
+    if ( my $user_rc_file = _get_user_rcfile() ) {
+        $file = $user_rc_file;
+    }
+
     my %hash;
     for my $d ( @{_array($dir)}, @{$RC_DIRS} ) {
         next unless $d;
@@ -54,6 +59,24 @@ sub read {
     return $RC = \%hash;
 }
 
+sub _get_user_rcfile {
+    return unless @ARGV;
+
+    my $f = 0;
+    my @rcfiles;
+    for my $opt (@ARGV) {
+        if ($f && $opt) {
+            push @rcfiles, $opt;
+            $f = 0;
+        }
+        elsif ($opt && $opt eq '--rc') {
+            $f = 1;
+        }
+    }
+
+    return \@rcfiles if @rcfiles;
+}
+
 sub _get_args {
     my ($file, $dir, $loader);
     if (@_ == 1) {
